==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Oblúky a Kružnice</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>do úsečiek (pevná dĺžka)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>do úsečiek (pevný uhol)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Elipsy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>do krivky s oblúkov</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>do krivky s úsečiek</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Spline-y</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Rozmery</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>do čiar, výplní a textov</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Šráfy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>do čiar</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Bloky</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>do prvkov</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Rozložiť</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Rozložiť</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Úsek Spline:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Úsek elipsy (celá elipsa):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Oblúky a Kružnice</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>do úsečiek (pevná dĺžka)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>do úsečiek (pevný uhol)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Elipsy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>do krivky s oblúkov</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>do krivky s úsečiek</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Spline-y</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Rozmery</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>do čiar, výplní a textov</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Šrafovania</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>do čiar</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Bloky</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>do prvkov</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Rozložiť</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Rozložiť</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Rozložiť text na krivky</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Úsek Spline:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Úsek elipsy (celá elipsa):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Rozložiť spline-u na krivky s čiarových úsekov</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Napísať(vykresliť) text pozdĺž prvku</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline - približná tolerancia:</translation>
    </message>
</context>
</TS>
